@@ -3,6 +3,7 @@ from . import _utils
 
 def skema(self, uge=None, år=None, id=None):
     skema = {
+        "overskrift": "",
         "modulTider": {},
         "ugeDage": [],
         "moduler": [],
@@ -10,29 +11,45 @@ def skema(self, uge=None, år=None, id=None):
     }
 
     url = f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?"
+    if id[0] == "U":
+        bruger = self.fåBruger(brugerId=id)
+        if bruger["type"] == "elev":
+            id = "S" + bruger["id"]
+        elif bruger["type"] == "lærer":
+            id = "T" + bruger["id"]
+
     if id == None:
         url += f"type=elev&elevid={self.elevId}"
         skema["hold"] = []
         skema["grupper"] = []
+        skema["type"] = "elev"
     elif id[0] == "S": # Elev
         url += f"type=elev&elevid={id[1:]}"
         skema["hold"] = []
         skema["grupper"] = []
+        skema["type"] = "elev"
     elif id[0] == "T": # Lærer
         url += f"type=laerer&laererid={id[1:]}"
         skema["hold"] = []
+        skema["type"] = "lærer"
+
     elif id[0] == "C": # Klasse
         url += f"type=stamklasse&klasseid={id[1:]}"
         skema["hold"] = []
         skema["grupper"] = []
+        skema["type"] = "klasse"
     elif id[0:2] == "RE": # Ressource
         url += f"type=lokale&nosubnav=1&id={id[2:]}"
+        skema["type"] = "ressource"
     elif id[0] == "R": # Lokale
         url += f"type=lokale&nosubnav=1&id={id[1:]}"
+        skema["type"] = "lokale"
     elif id[0:2] == "HE": # Hold Element
         url += f"type=holdelement&holdelementid={id[2:]}"
+        skema["type"] = "hold"
     elif id[0] == "G": # Gruppe
         url += f"type=holdelement&holdelementid={id[1:]}"
+        skema["type"] = "gruppe"
 
     if uge != None and år != None:
         uge = str(uge)
@@ -50,6 +67,8 @@ def skema(self, uge=None, år=None, id=None):
 
     soup = BeautifulSoup(resp.text, "html.parser")
 
+    skema["overskrift"] = soup.find("div", {"id": "s_m_HeaderContent_MainTitle"}).text
+
     if id == None or id[0] == "S" or id[0] == "C":
         holdOgGrupper = soup.find("div", {"id": "s_m_Content_Content_holdElementLinkList"})
         for tr in holdOgGrupper.find_all("tr"):
@@ -92,4 +111,13 @@ def skema(self, uge=None, år=None, id=None):
                 skema["moduler"].append(modulDict)
         i += 1
 
-    return skema
\ No newline at end of file
+    return skema
+
+def holdTilFag(self, holdId):
+    url = f"https://www.lectio.dk/lectio/{self.skoleId}/contextcard/contextcard.aspx?lectiocontextcard={holdId}"
+    resp = self.session.get(url)
+    if resp.url != url:
+        raise Exception("lectio-cookie udløbet")
+    soup = BeautifulSoup(resp.text, "html.parser")
+
+    return {"fag": soup.find("td", {"class": "textTop"}).find_all("td")[1].text}
\ No newline at end of file
